@@ -177,7 +177,11 @@ struct ProcessedToken {
 
    ProcessedToken(ProcessedTokenType t, const std::string& s) : type(t) {
       assert(t == ProcessedTokenType::CONID || t == ProcessedTokenType::VARID);
+#ifndef _WIN32
       name = strdup(s.c_str());
+#else
+      name = _strdup(s.c_str());
+#endif
    };
 
    ProcessedToken(double v) : type(ProcessedTokenType::CONST), value(v) {};
@@ -666,7 +670,7 @@ void Reader::processgensec() {
 }
 
 void Reader::processsemisec() {
-   if(!sectiontokens.count(LpSectionKeyword::GEN))
+   if(!sectiontokens.count(LpSectionKeyword::SEMI))
       return;
    std::vector<ProcessedToken>::iterator& begin(sectiontokens[LpSectionKeyword::SEMI].first);
    std::vector<ProcessedToken>::iterator& end(sectiontokens[LpSectionKeyword::SEMI].second);
