@@ -25,6 +25,21 @@
 #include "presolve/ICrash.h"
 #include "presolve/PresolveComponent.h"
 
+/**
+ * @brief Return the version as a string
+ */
+std::string highsVersion();
+
+/**
+ * @brief Return detailed version information, githash and compilation
+ * date
+ */
+HighsInt highsVersionMajor();
+HighsInt highsVersionMinor();
+HighsInt highsVersionPatch();
+std::string highsGithash();
+std::string highsCompilationDate();
+
 /**
  * @brief Class to set parameters and run HiGHS
  */
@@ -150,10 +165,12 @@ class Highs {
                            const HighsInt style = kSolutionStyleRaw);
 
   /**
-   * @brief Check the feasibility of the current solution. Of value
-   * after calling Highs::readSolution
+   * @brief Assess the validity, integrality and feasibility of the
+   * current primal solution. Of value after calling
+   * Highs::readSolution
    */
-  HighsStatus checkSolutionFeasibility() const;
+  HighsStatus assessPrimalSolution(bool& valid, bool& integral,
+                                   bool& feasible) const;
 
   /**
    * Methods for HiGHS option input/output
@@ -1119,8 +1136,7 @@ class Highs {
     this->model_.lp_.exactResize();
     this->model_.hessian_.exactResize();
   }
-
-  HighsStatus assessContinuousMipSolution();
+  HighsStatus assignContinuousAtDiscreteSolution();
 
   HighsStatus callSolveLp(HighsLp& lp, const string message);
   HighsStatus callSolveQp();
@@ -1182,6 +1198,8 @@ class Highs {
   // Invalidates ekk_instance_
   void invalidateEkk();
 
+  HighsStatus returnFromWriteSolution(FILE* file,
+                                      const HighsStatus return_status);
   HighsStatus returnFromRun(const HighsStatus return_status);
   HighsStatus returnFromHighs(const HighsStatus return_status);
   void reportSolvedLpQpStats();
