@@ -382,6 +382,13 @@ OptionStatus setLocalOptionValue(const HighsLogOptions& report_log_options,
   if (status != OptionStatus::kOk) return status;
   HighsOptionType type = option_records[index]->type;
   if (type != HighsOptionType::kInt) {
+    if (type == HighsOptionType::kDouble) {
+      // Interpret integer as double
+      double use_value = value;
+      return setLocalOptionValue(
+          report_log_options, ((OptionRecordDouble*)option_records[index])[0],
+          use_value);
+    }
     highsLogUser(
         report_log_options, HighsLogType::kError,
         "setLocalOptionValue: Option \"%s\" cannot be assigned an int\n",
