@@ -167,7 +167,7 @@ void HighsCutPool::performAging() {
     }
   }
 
-  assert(propRows.size() == numPropRows);
+  assert((HighsInt)propRows.size() == numPropRows);
 }
 
 void HighsCutPool::separate(const std::vector<double>& sol, HighsDomain& domain,
@@ -274,7 +274,7 @@ void HighsCutPool::separate(const std::vector<double>& sol, HighsDomain& domain,
 
     efficacious_cuts.emplace_back(score, i);
   }
-  assert(propRows.size() == numPropRows);
+  assert((HighsInt)propRows.size() == numPropRows);
   if (efficacious_cuts.empty()) return;
 
   pdqsort(efficacious_cuts.begin(), efficacious_cuts.end(),
@@ -364,7 +364,7 @@ void HighsCutPool::separate(const std::vector<double>& sol, HighsDomain& domain,
     }
   }
 
-  assert(propRows.size() == numPropRows);
+  assert((HighsInt)propRows.size() == numPropRows);
   cutset.ARstart_[cutset.numCuts()] = offset;
 }
 
@@ -404,7 +404,7 @@ void HighsCutPool::separateLpCutsAfterRestart(HighsCutSet& cutset) {
 
   cutset.ARstart_[cutset.numCuts()] = offset;
 
-  assert(propRows.size() == numPropRows);
+  assert((HighsInt)propRows.size() == numPropRows);
 }
 
 HighsInt HighsCutPool::addCut(const HighsMipSolver& mipsolver, HighsInt* Rindex,
@@ -511,7 +511,7 @@ HighsInt HighsCutPool::addCut(const HighsMipSolver& mipsolver, HighsInt* Rindex,
   ++ageDistribution[ages_[rowindex]];
   rowintegral[rowindex] = integral;
   if (propagate) propRows.emplace(ages_[rowindex], rowindex);
-  assert(propRows.size() == numPropRows);
+  assert((HighsInt)propRows.size() == numPropRows);
 
   rownormalization_[rowindex] = normalization;
   maxabscoef_[rowindex] = maxabscoef;
