@@ -31,12 +31,16 @@
 #ifdef HIGHS_HAVE_BITSCAN_REVERSE
 #include <intrin.h>
 #pragma intrinsic(_BitScanReverse)
+#ifdef _WIN64
 #pragma intrinsic(_BitScanReverse64)
 #pragma intrinsic(__popcnt64)
+#else
+#pragma intrinsic(__popcnt)
+#endif
 #endif
 
 #if __GNUG__ && __GNUC__ < 5
-#define IS_TRIVIALLY_COPYABLE(T) __is_trivially_copyable(T)
+#define IS_TRIVIALLY_COPYABLE(T) __has_trivial_copy(T)
 #else
 #define IS_TRIVIALLY_COPYABLE(T) std::is_trivially_copyable<T>::value
 #endif
@@ -109,7 +113,14 @@ struct HighsHashHelpers {
 #elif defined(HIGHS_HAVE_BITSCAN_REVERSE)
   static int log2i(uint64_t n) {
     unsigned long result;
+#ifdef _WIN64
     _BitScanReverse64(&result, n);
+#else
+    if (_BitScanReverse(&result, (n >> 32)))
+      result += 32;
+    else
+      _BitScanReverse(&result, (n & 0xffffffffu));
+#endif
     return result;
   }
 
@@ -119,7 +130,13 @@ struct HighsHashHelpers {
     return result;
   }
 
-  static int popcnt(uint64_t x) { return __popcnt64(x); }
+  static int popcnt(uint64_t x) {
+#ifdef _WIN64
+    return __popcnt64(x);
+#else
+    return __popcnt(x & 0xffffffffu) + __popcnt(x >> 32);
+#endif
+  }
 #else
   // integer log2 algorithm without floating point arithmetic. It uses an
   // unrolled loop and requires few instructions that can be well optimized.
