@@ -5,11 +5,35 @@
 using namespace Rcpp;
 
 
+/*
+class HighsR: public Highs {
+    public:
+
+    void set_ncol(int32_t ncol) {
+        model_.lp_.num_col_ = ncol;
+    }
+
+};
+*/
+
+
 static void R_message_handler(HighsLogType type, const char* message, void* log_callback_data) {
   Rcpp::Rcout << message << std::endl;
 }
 
 
+std::vector<HighsVarType> to_vartype(std::vector<int32_t> type) {
+    std::vector<HighsVarType> htype;
+    std::vector<HighsVarType> variable_types = {
+        HighsVarType::kContinuous, HighsVarType::kInteger, HighsVarType::kSemiContinuous,
+        HighsVarType::kSemiInteger, HighsVarType::kImplicitInteger};
+    for (std::size_t i = 0; i < type.size(); ++i) {
+        htype.push_back(variable_types[type[i]]);
+    }
+    return htype;
+}
+
+
 // [[Rcpp::export]]
 SEXP new_model() {
     Rcpp::XPtr<HighsModel> highs_model(new HighsModel(), true);
@@ -70,10 +94,10 @@ SEXP model_set_upper(SEXP mpt, std::vector<double> upper) {
 }
 
 // [[Rcpp::export]]
-SEXP model_set_constraint_matrix(SEXP mpt, std::string format,
-                                 std::vector<int32_t> start,
-                                 std::vector<int32_t> index,
-                                 std::vector<double> value) {
+SEXP model_set_constraint_matrix_(SEXP mpt, std::string format,
+                                  std::vector<int32_t> start,
+                                  std::vector<int32_t> index,
+                                  std::vector<double> value) {
     Rcpp::XPtr<HighsModel>model(mpt);
     if (format == "colwise") {
         model->lp_.a_matrix_.format_ = MatrixFormat::kColwise;
@@ -105,10 +129,10 @@ SEXP model_set_rhs(SEXP mpt, std::vector<double> upper) {
 }
 
 // [[Rcpp::export]]
-SEXP model_set_hessian(SEXP mpt, std::string format, int32_t dim,
-                       std::vector<int32_t> start,
-                       std::vector<int32_t> index,
-                       std::vector<double> value) {
+SEXP model_set_hessian_(SEXP mpt, std::string format, int32_t dim,
+                        std::vector<int32_t> start,
+                        std::vector<int32_t> index,
+                        std::vector<double> value) {
     Rcpp::XPtr<HighsModel>model(mpt);
     model->hessian_.dim_ = dim;
     if (format == "triangular") {
@@ -151,21 +175,33 @@ int32_t model_get_ncons(SEXP mpt) {
     return static_cast<int32_t>(model->lp_.num_row_);
 }
 
-// [[Rcpp::export]]
-Rcpp::IntegerVector model_get_vartype(SEXP mpt) {
-    Rcpp::XPtr<HighsModel>model(mpt);
-    IntegerVector type(model->lp_.integrality_.size());
-    for (R_xlen_t i = 0; i < type.size(); ++i) {
-        type[i] = static_cast<int32_t>(model->lp_.integrality_[i]);
-    }
-    return type;
+
+RCPP_MODULE(RcppHighs) {
+    class_<Highs>("Highs")
+
+    .constructor()
+
+    
+    .method("getObjectiveValue", &Highs::getObjectiveValue)
+    .method("getNumCol", &Highs::getNumCol)
+    .method("getNumRow", &Highs::getNumRow)
+    .method("getNumNz", &Highs::getNumNz)
+    .method("getHessianNumNz", &Highs::getHessianNumNz)
+    // .method("getObjectiveSense", &Highs::getObjectiveSense)
+    // .method("getObjectiveOffset", &Highs::getObjectiveOffset)
+
+    ;
 }
 
+
 // [[Rcpp::export]]
 SEXP new_solver(SEXP mpt) {
-    Rcpp::XPtr<HighsModel>model(mpt);
     Rcpp::XPtr<Highs> highs(new Highs(), true);
     highs->setLogCallback(R_message_handler);
+    if (Rf_isNull(mpt)) {
+        return highs;
+    }
+    Rcpp::XPtr<HighsModel>model(mpt);
     HighsStatus return_status = highs->passModel(*model.get());
     if (return_status != HighsStatus::kOk) {
         return R_NilValue;
@@ -173,6 +209,156 @@ SEXP new_solver(SEXP mpt) {
     return highs;
 }
 
+
+// [[Rcpp::export]]
+SEXP highs_pass_model(SEXP hi,
+                   const int32_t num_col, const int32_t num_row,
+                   const int32_t num_nz, const int32_t a_format,
+                   const int32_t sense, const double_t offset,
+                   NumericVector col_cost, NumericVector col_lower,
+                   NumericVector col_upper, NumericVector row_lower,
+                   NumericVector row_upper, IntegerVector a_start,
+                   IntegerVector a_index, NumericVector a_value,
+                   IntegerVector integrality) {
+    Rcpp::XPtr<Highs>highs(hi);
+    highs->passModel(num_col,
+                     num_row,
+                     num_nz,
+                     a_format,
+                     sense,
+                     offset,
+                     &(col_cost[0]),
+                     &(col_lower[0]),
+                     &(col_upper[0]),
+                     &(row_lower[0]),
+                     &(row_upper[0]),
+                     &(a_start[0]),
+                     &(a_index[0]),
+                     &(a_value[0]),
+                     &(integrality[0]));
+    return R_NilValue;
+}
+
+
+// [[Rcpp::export]]
+SEXP solver_pass_hessian() {
+    return R_NilValue;
+}
+
+
+// [[Rcpp::export]]
+SEXP solver_pass_constraints () {
+    return R_NilValue;
+}
+
+
+// [[Rcpp::export]]
+int32_t solver_get_sense(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    ObjSense sense;
+    HighsStatus status = highs->getObjectiveSense(sense);
+    return sense == ObjSense::kMaximize;
+}
+
+// [[Rcpp::export]]
+int32_t solver_set_sense(SEXP hi, bool maximum) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsStatus status;
+    if (maximum) {
+        status = highs->changeObjectiveSense(ObjSense::kMaximize);
+    } else {
+        status = highs->changeObjectiveSense(ObjSense::kMinimize);
+    }
+    return static_cast<int32_t>(status);
+}
+
+// [[Rcpp::export]]
+int32_t solver_set_offset(SEXP hi, const double ext_offset) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsStatus status = highs->changeObjectiveOffset(ext_offset);
+    return static_cast<int32_t>(status);
+}
+
+// [[Rcpp::export]]
+int32_t solver_set_integrality(SEXP hi, std::vector<int32_t> index, std::vector<int32_t> type) {
+    Rcpp::XPtr<Highs>highs(hi);
+    const int32_t num_set_entries = index.size();
+    const HighsInt* set = &(index[0]);
+    const HighsVarType* integrality = &(to_vartype(type)[0]);
+    HighsStatus status = highs->changeColsIntegrality(num_set_entries, set, integrality);
+    return static_cast<int32_t>(status);
+}
+
+// [[Rcpp::export]]
+int32_t solver_set_objective(SEXP hi, std::vector<int32_t> index, std::vector<double_t> obj) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsStatus status = highs->changeColsCost(index.size(), &(index[0]), &(obj[0]));
+    return static_cast<int32_t>(status);
+}
+
+
+// [[Rcpp::export]]
+int32_t solver_set_variable_bounds(SEXP hi, std::vector<int32_t> index, std::vector<double_t> lower, std::vector<double_t> upper) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsStatus status = highs->changeColsBounds(index.size(), &(index[0]), &(lower[0]), &(upper[0]));
+    return static_cast<int32_t>(status);
+}
+
+
+// [[Rcpp::export]]
+int32_t solver_set_constraint_bounds(SEXP hi, std::vector<int32_t> index, std::vector<double_t> lower, std::vector<double_t> upper) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsStatus status = highs->changeRowsBounds(index.size(), &(index[0]), &(lower[0]), &(upper[0]));
+    return static_cast<int32_t>(status);
+}
+
+
+// [[Rcpp::export]]
+SEXP solver_set_coeff(SEXP hi, std::vector<int32_t> row, std::vector<int32_t> col, std::vector<double_t> val) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsStatus status;
+    for (std::size_t i = 0; i < row.size(); ++i) {
+        status = highs->changeCoeff(row[i], col[i], val[i]);
+        if (status != HighsStatus::kOk) {
+            Rcpp::stop("error setting coefficient");
+        }
+    }
+    return R_NilValue;
+}
+
+
+// [[Rcpp::export]]
+int32_t solver_add_vars(SEXP hi, std::vector<double_t> lower, std::vector<double_t> upper) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsStatus status = highs->addVars(lower.size(), &(lower[0]), &(upper[0]));
+    return static_cast<int32_t>(status);
+}
+
+/*
+model_set_lower
+model_set_upper
+model_set_constraint_matrix_
+model_set_lhs
+model_set_rhs
+model_set_hessian_
+model_set_vartype
+*/
+//
+// changeObjectiveSenseInterface
+// 
+// addRowsInterface
+// addColsInterface
+// changeColsIntegrality
+// changeColsCost
+// changeColsBounds
+// changeRowsBounds
+// changeCoeff
+// addCols
+// addRows
+// setSolution
+// getHotStart
+// setHotStart
+
 // [[Rcpp::export]]
 int32_t solver_set_option(SEXP hi, std::string key, SEXP value) {
     Rcpp::XPtr<Highs>highs(hi);
@@ -229,6 +415,30 @@ int32_t solver_run(SEXP hi) {
 }
 
 
+// [[Rcpp::export]]
+SEXP solver_get_model(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsModel mpt = highs->getModel();
+    Rcpp::XPtr<HighsModel> highs_model(&mpt, true);
+    return highs_model;
+}
+
+
+// [[Rcpp::export]]
+int32_t solver_get_num_col(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    return highs->getNumCol();
+}
+
+
+// [[Rcpp::export]]
+int32_t solver_get_num_row(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    return highs->getNumRow();
+}
+
+
+
 //
 // int32_t solver_presolve(SEXP hi) {
 //     Rcpp::XPtr<Highs>highs(hi);
@@ -374,7 +584,7 @@ std::string solver_get_str_option(SEXP hi, std::string key) {
 
 
 // [[Rcpp::export]]
-int32_t solver_change_bounds(SEXP hi, IntegerVector idx, NumericVector lower, NumericVector upper) {
+int32_t solver_change_variable_bounds(SEXP hi, IntegerVector idx, NumericVector lower, NumericVector upper) {
     Rcpp::XPtr<Highs>highs(hi);
     HighsStatus return_status = highs->changeColsBounds(idx.size(), &(idx[0]), &(lower[0]), &(upper[0]));
     return static_cast<int32_t>(return_status);
@@ -382,7 +592,7 @@ int32_t solver_change_bounds(SEXP hi, IntegerVector idx, NumericVector lower, Nu
 
 
 // [[Rcpp::export]]
-int32_t solver_change_lrhs(SEXP hi, IntegerVector idx, NumericVector lhs, NumericVector rhs) {
+int32_t solver_change_constraint_bounds(SEXP hi, IntegerVector idx, NumericVector lhs, NumericVector rhs) {
     Rcpp::XPtr<Highs>highs(hi);
     HighsStatus return_status = highs->changeRowsBounds(idx.size(), &(idx[0]), &(lhs[0]), &(rhs[0]));
     return static_cast<int32_t>(return_status);
@@ -424,3 +634,74 @@ int32_t solver_add_cols(SEXP hi, NumericVector costs,
     return static_cast<int32_t>(return_status);
 }
 
+
+// [[Rcpp::export]]
+Rcpp::NumericVector solver_get_lp_costs(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    int32_t nvar = highs->getNumCol();
+    NumericVector costs(nvar);
+    HighsModel model = highs->getModel();
+    for (int32_t i = 0; i < nvar; i++) {
+        costs[i] = model.lp_.col_cost_[i];
+    }
+    return costs;
+}
+
+
+// [[Rcpp::export]]
+Rcpp::NumericVector solver_get_variable_bounds(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    int32_t nvar = highs->getNumCol();
+    NumericVector vbounds(2 * nvar);
+    HighsModel model = highs->getModel();
+    for (int32_t i = 0; i < nvar; i++) {
+        vbounds[i] = model.lp_.col_lower_[i];
+        vbounds[nvar + i] = model.lp_.col_upper_[i];
+    }
+    return vbounds;
+}
+
+
+// [[Rcpp::export]]
+Rcpp::NumericVector solver_get_constraint_bounds(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    int32_t nvar = highs->getNumCol();
+    NumericVector lhs_rhs(2 * nvar);
+    HighsModel model = highs->getModel();
+    for (int32_t i = 0; i < nvar; i++) {
+        lhs_rhs[i] = model.lp_.row_lower_[i];
+        lhs_rhs[nvar + i] = model.lp_.row_upper_[i];
+    }
+    return lhs_rhs;
+}
+
+
+// [[Rcpp::export]]
+Rcpp::List solver_get_constraint_matrix(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    HighsModel model = highs->getModel();
+    HighsSparseMatrix A = model.lp_.a_matrix_;
+    List z = List::create(
+        Named("format") = static_cast<int32_t>(A.format_),
+        Named("nrow") = A.num_row_,
+        Named("ncol") = A.num_col_,
+        Named("start") = A.start_,
+        Named("p_end") = A.p_end_,
+        Named("index") = A.index_,
+        Named("value") = A.value_
+    );
+    return z;
+}
+
+
+// [[Rcpp::export]]
+Rcpp::IntegerVector solver_get_vartype(SEXP hi) {
+    Rcpp::XPtr<Highs>highs(hi);
+    const HighsLp& lp = highs->getLp();
+    int32_t m = lp.integrality_.size();
+    IntegerVector type(m);
+    for (int32_t i = 0; i < type.size(); ++i) {
+        type[i] = static_cast<int32_t>(lp.integrality_[i]);
+    }
+    return type;
+}
